#
# Copyright (c) 2008-2018 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'

from zope.interface import Interface

from onf_website.component.hearing import IHearingInfo
from onf_website.skin.public.layer import IONFBaseLayer
from pyams_content.features.search import ISearchFolder
from pyams_content.shared.common import IWfSharedContent
from pyams_content.shared.common.interfaces.types import IWfTypedSharedContent
from pyams_content.shared.common.portlet.interfaces import ISharedContentHeaderPortletSettings
from pyams_default_theme.features.search.portlet import SearchResultsPortletDefaultRenderer, \
    WfSharedContentSearchResultRenderer, SearchResultsPortletPanelsRenderer, \
    WfSharedContentSearchResultPanelRenderer
from pyams_default_theme.interfaces import ISearchResultsView
from pyams_default_theme.shared.common.interfaces import ISharedContentHeadViewletManager
from pyams_default_theme.shared.common.portlet.head import SharedContentHeaderPortletRenderer
from pyams_portal.interfaces import IPortletRenderer
from pyams_skin.interfaces.viewlet import IBreadcrumbs
from pyams_skin.viewlet.breadcrumb import BreadcrumbsAdapter as BaseBreadcrumbsAdapter, \
    BreadcrumbsAdapter
from pyams_template.template import override_template, template_config
from pyams_utils.adapter import adapter_config
from pyams_viewlet.viewlet import Viewlet, viewlet_config
from pyams_workflow.interfaces import IWorkflowPublicationInfo


#
# Search folder head and specificities
#

@adapter_config(context=(ISearchFolder, IONFBaseLayer, Interface, ISharedContentHeaderPortletSettings),
                provides=IPortletRenderer)
@template_config(template='templates/head.pt', layer=IONFBaseLayer)
class SearchFolderHeaderPortletRenderer(SharedContentHeaderPortletRenderer):
    """Search folder header portlet default renderer"""


@viewlet_config(name='search-folder-head', context=ISearchFolder, layer=IONFBaseLayer, view=Interface,
                manager=ISharedContentHeadViewletManager, weight=1)
@template_config(template='templates/head-specificities.pt', layer=IONFBaseLayer)
class SearchFolderHeadViewlet(Viewlet):
    """Search folder head specificities viewlet"""


#
# Search folder breadcrumbs
#

@adapter_config(context=(ISearchFolder, IONFBaseLayer, Interface), provides=IBreadcrumbs)
class SearchFolderBreadcrumbsAdapter(BreadcrumbsAdapter):
    """Search folder breadcrumbs adapter

    Use default breadcrumbs adapter.
    """


#
# Custom renderers templates
#

override_template(context=SearchResultsPortletDefaultRenderer,
                  template='templates/search-results.pt', layer=IONFBaseLayer)


override_template(context=WfSharedContentSearchResultRenderer,
                  template='templates/search-result.pt', layer=IONFBaseLayer)


override_template(context=SearchResultsPortletPanelsRenderer,
                  template='templates/search-panels.pt', layer=IONFBaseLayer)


override_template(context=WfSharedContentSearchResultPanelRenderer,
                  template='templates/search-panel.pt', layer=IONFBaseLayer)


#
# Custom breadcrumbs adapter
#

@adapter_config(context=(IWfSharedContent, IONFBaseLayer, ISearchResultsView), provides=IBreadcrumbs)
@adapter_config(context=(IWfTypedSharedContent, IONFBaseLayer, ISearchResultsView), provides=IBreadcrumbs)
class BreadcrumbsAdapter(BaseBreadcrumbsAdapter):
    """Custom search results breadcrumbs adapter"""

    @property
    def items(self):
        hearing = IHearingInfo(self.context, None)
        if hearing is not None:
            source = hearing.get_source_folder()
            if source is None:
                source = hearing.get_source_site()
            if source is not None:
                publication_info = IWorkflowPublicationInfo(source)
                if publication_info.is_visible(self.request):
                    yield from self.get_items(source)
